unit DevToolsWin;

interface

uses
  Windows, Messages, SysUtils, Variants, Classes, Graphics, Controls, Forms,
  Dialogs, XPMan, XPMenu, Menus, ComCtrls, VampyreAboutDlg, Registry,
  ExtCtrls, StdCtrls, Buttons, WinUtils, FileCtrl;

type
  TDevToolsForm = class(TForm)
    Pages: TPageControl;
    MainMenu: TMainMenu;
    File1: TMenuItem;
    Exit1: TMenuItem;
    Help1: TMenuItem;
    About1: TMenuItem;
    XPMan: TXPManifest;
    XPMenu: TXPMenu;
    PageBackUp: TTabSheet;
    PageSrcSize: TTabSheet;
    PageCleaner: TTabSheet;
    View1: TMenuItem;
    SourceBackUp1: TMenuItem;
    SourceSizeCounter1: TMenuItem;
    DirectoryCleaner1: TMenuItem;
    QuickExecute1: TMenuItem;
    SourceBackUp2: TMenuItem;
    SourceSizeCounter2: TMenuItem;
    DirectoryCleaner2: TMenuItem;
    GroupBox1: TGroupBox;
    ListBackUpTypes: TListBox;
    Button1: TButton;
    Button2: TButton;
    CheckBackUpAllTypes: TCheckBox;
    BitBtn1: TBitBtn;
    GroupBox2: TGroupBox;
    EditBackUpNewDir: TLabeledEdit;
    ListBackUpSrcDirs: TListBox;
    Button4: TButton;
    Btrn: TButton;
    GroupBox3: TGroupBox;
    ListBackUpDestDirs: TListBox;
    Button3: TButton;
    Button5: TButton;
    GroupSrcSize: TGroupBox;
    ListSrcSizeTypes: TListBox;
    BtnSrcSizeNewType: TButton;
    Button7: TButton;
    CheckSrcSizeAllTypes: TCheckBox;
    GroupBox4: TGroupBox;
    ListSrcSizeDirs: TListBox;
    Button6: TButton;
    Button8: TButton;
    BitBtn2: TBitBtn;
    BitBtn3: TBitBtn;
    GroupBox5: TGroupBox;
    ListDirCleanTypes: TListBox;
    Button9: TButton;
    Button10: TButton;
    GroupBox6: TGroupBox;
    ListDirCleanDirs: TListBox;
    Button11: TButton;
    Button12: TButton;
    procedure About1Click(Sender: TObject);
    procedure FormCreate(Sender: TObject);
    procedure FormDestroy(Sender: TObject);
    procedure Exit1Click(Sender: TObject);
    procedure FormClose(Sender: TObject; var Action: TCloseAction);
    procedure FormActivate(Sender: TObject);
    procedure Button1Click(Sender: TObject);
    procedure Button2Click(Sender: TObject);
    procedure BtrnClick(Sender: TObject);
    procedure Button3Click(Sender: TObject);
    procedure Button4Click(Sender: TObject);
    procedure Button5Click(Sender: TObject);
    procedure BitBtn1Click(Sender: TObject);
    procedure SourceBackUp2Click(Sender: TObject);
    procedure BtnSrcSizeNewTypeClick(Sender: TObject);
    procedure Button7Click(Sender: TObject);
    procedure Button6Click(Sender: TObject);
    procedure Button8Click(Sender: TObject);
    procedure BitBtn3Click(Sender: TObject);
    procedure Button9Click(Sender: TObject);
    procedure Button10Click(Sender: TObject);
    procedure Button11Click(Sender: TObject);
    procedure Button12Click(Sender: TObject);
    procedure BitBtn2Click(Sender: TObject);
    procedure SourceSizeCounter2Click(Sender: TObject);
    procedure DirectoryCleaner2Click(Sender: TObject);
    procedure SourceBackUp1Click(Sender: TObject);
    procedure SourceSizeCounter1Click(Sender: TObject);
    procedure DirectoryCleaner1Click(Sender: TObject);
  private
    FFirstShow: boolean;
    FSelDirRoot: string;
    { Private declarations }
  public

    procedure CmdAbout;
    procedure CmdExit;
    procedure CmdWriteSettings;
    procedure CmdReadSettings;
    procedure CmdFirstRun;

    procedure CmdBackUpNewType;
    procedure CmdBackUpRemoveType;
    procedure CmdBackUpNewSrcDir;
    procedure CmdBackUpNewDestDir;
    procedure CmdBackUpRemoveSrcDir;
    procedure CmdBackUpRemoveDestDir;
    procedure CmdBackUpProcess;

    procedure CmdSrcSizeNewType;
    procedure CmdSrcSizeRemoveType;
    procedure CmdSrcSizeNewDir;
    procedure CmdSrcSizeRemoveDir;
    procedure CmdSrcSizeProcess;

    procedure CmdDirCleanNewType;
    procedure CmdDirCleanRemoveType;
    procedure CmdDirCleanNewDir;
    procedure CmdDirCleanRemoveDir;
    procedure CmdDirCleanProcess;


    { Public declarations }
  end;

const

  sApp = 'Vampyre Developer Tools';
  sAppVer = '0.40  17.12.2002';


  sBackUpDir='BackUp';

  ExtsBackUpDef: array[0..19] of string =
  ('.pas', '.dpr', '.dfm', '.bpg', '.dpk',
    '.dpkw', '.xfm', '.res', '.dof', '.dsk',
    '.cfg','.asm','.cpp','.h','.hpp',
    '.dsw','.dsp','.mak','.lib','.rc');

  ExtsSrcSizeDef: array[0..9] of string =
  ('.pas', '.dpr', '.cpp', '.h', '.hpp',
  '.c','.inc','.asm','.py','.pp');

  ExtsDirCleanDef: array[0..19] of string =
  ('.~pas', '.bak', '.~res', '.~dpr', '.~dpr',
    '.~dpkw', '.~xfm', '.dcu', '.~bpg', '.~cpp',
    '.~hpp','.tmp','.~h','.~c','.$$$',
    '.ddp','.~ddp','.~dsk','.bk1','.bk2');


  sKeyApp = 'SoftWare\Vampyre SoftWorks\Utils\Developer Tools';
  sKeyBackUp = 'Source BackUp';
  sKeySrcSize = 'Source Size';
  sKeyDirClean = 'Dir Cleaner';


var
  DevToolsForm: TDevToolsForm;

implementation

uses SourceBackUP,SourceSize,DirCleaner;

{$R *.dfm}

procedure TDevToolsForm.FormCreate(Sender: TObject);
begin
  FFirstShow := true;
  FSelDirRoot:='';

  EditBackUpNewDir.Text:=sBackUpDir;
end;

procedure TDevToolsForm.FormDestroy(Sender: TObject);
begin
//
end;

procedure TDevToolsForm.CmdAbout;
begin
  if AboutForm = nil then
  begin
    Application.CreateForm(TAboutForm, AboutForm);
    AboutForm.Memo.Lines.Insert(0, sApp);
    AboutForm.Memo.Lines.Insert(1, sAppVer);
  end;
  AboutForm.ShowModal;
end;

procedure TDevToolsForm.CmdExit;
begin
  Close;
end;

procedure TDevToolsForm.CmdWriteSettings;
var Reg: TRegistry;
  S: string;
begin
  Reg := TRegistry.Create(KEY_ALL_ACCESS);
  Reg.RootKey := HKEY_LOCAL_MACHINE;

 // setting for source backup
  Reg.OpenKey(sKeyApp + '\' + sKeyBackUp, true);

  S:=ComposeString(ListBackUpTypes.Items,';');
  Reg.WriteString('File Types', S);
  S:=ComposeString(ListBackUpSrcDirs.Items,';');
  Reg.WriteString('Src Dirs', S);
  S:=ComposeString(ListBackUpDestDirs.Items,';');
  Reg.WriteString('Dest Dirs', S);
  Reg.WriteString('New Dir',EditBackUpNewDir.Text);
  Reg.WriteBool('All Types',CheckBackUpAllTypes.Checked);

  Reg.CloseKey;


 // setting for source size
  Reg.OpenKey(sKeyApp + '\' + sKeySrcSize, true);

  S:=ComposeString(ListSrcSizeTypes.Items,';');
  Reg.WriteString('File Types', S);
  S:=ComposeString(ListSrcSizeDirs.Items,';');
  Reg.WriteString('Dirs', S);
  Reg.WriteBool('All Types',CheckSrcSizeAllTypes.Checked);

  Reg.CloseKey;


 // setting for dir cleaner
  Reg.OpenKey(sKeyApp + '\' + sKeyDirClean, true);

  S:=ComposeString(ListDirCleanTypes.Items,';');
  Reg.WriteString('File Types', S);
  S:=ComposeString(ListDirCleanDirs.Items,';');
  Reg.WriteString('Dirs', S);
 
  Reg.CloseKey;


  Reg.Free;

end;

procedure TDevToolsForm.CmdReadSettings;
var Reg: TRegistry;
  S: string;
begin
  Reg := TRegistry.Create(KEY_ALL_ACCESS);
  Reg.RootKey := HKEY_LOCAL_MACHINE;
  if not Reg.KeyExists(sKeyApp) then
    CmdFirstRun;

  // settings for program

 // setting for source backup
  Reg.OpenKey(sKeyApp + '\' + sKeyBackUp, true);

  S := Reg.ReadString('File Types');
  StrTokenToStrings(S, ';', ListBackUpTypes.Items);
  S := Reg.ReadString('Src Dirs');
  StrTokenToStrings(S, ';', ListBackUpSrcDirs.Items);
  S := Reg.ReadString('Dest Dirs');
  StrTokenToStrings(S, ';', ListBackUpDestDirs.Items);
  EditBackUpNewDir.Text:=Reg.ReadString('New Dir');
  CheckBackUpAllTypes.Checked:=Reg.ReadBool('All Types');

  Reg.CloseKey;



 // setting for source size
  Reg.OpenKey(sKeyApp + '\' + sKeySrcSize, true);

  S := Reg.ReadString('File Types');
  StrTokenToStrings(S, ';', ListSrcSizeTypes.Items);
  S := Reg.ReadString('Dirs');
  StrTokenToStrings(S, ';', ListSrcSizeDirs.Items);
  CheckSrcSizeAllTypes.Checked:=Reg.ReadBool('All Types');


  Reg.CloseKey;


 // setting for dir cleaner
  Reg.OpenKey(sKeyApp + '\' + sKeyDirClean, true);

  S := Reg.ReadString('File Types');
  StrTokenToStrings(S, ';', ListDirCleanTypes.Items);
  S := Reg.ReadString('Dirs');
  StrTokenToStrings(S, ';', ListDirCleanDirs.Items);

  Reg.CloseKey;


  Reg.Free;
end;

procedure TDevToolsForm.CmdFirstRun;
var Reg: TRegistry;
  S: string;
  I: LongInt;
begin
  MessageDlg('You are running Vampyre Developer Tools for first time.' +
    #10 + 'Program will use default settings.', mtInformation, [mbOK], 0);

  Reg := TRegistry.Create(KEY_ALL_ACCESS);
  Reg.RootKey := HKEY_LOCAL_MACHINE;

 // setting for source backup
  Reg.OpenKey(sKeyApp + '\' + sKeyBackUp, true);

  S := '';
  for I := 0 to High(ExtsBackUpDef) do
    S := S + ExtsBackUpDef[I] + ';';
  Delete(S, Length(S), 1);
  Reg.WriteString('File Types', S);
  Reg.WriteString('New Dir','Project');
  Reg.WriteString('Src Dirs','');
  Reg.WriteString('Dest Dir','');
  Reg.WriteBool('All Types',false);

  Reg.CloseKey;


 // setting for source size
  Reg.OpenKey(sKeyApp + '\' + sKeySrcSize, true);

  S := '';
  for I := 0 to High(ExtsSrcSizeDef) do
    S := S + ExtsSrcSizeDef[I] + ';';
  Delete(S, Length(S), 1);
  Reg.WriteString('File Types', S);
  Reg.WriteString('Dirs','');
  Reg.WriteBool('All Types',false);

  Reg.CloseKey;


 // setting for dir cleaner
  Reg.OpenKey(sKeyApp + '\' + sKeyDirClean, true);

  S := '';
  for I := 0 to High(ExtsDirCleanDef) do
    S := S + ExtsDirCleanDef[I] + ';';
  Delete(S, Length(S), 1);
  Reg.WriteString('File Types', S);
  Reg.WriteString('Dirs','');


  Reg.CloseKey;


  Reg.Free;

end;


procedure TDevToolsForm.CmdBackUpNewType;
var S: string;
begin
  if InputQuery('New File Type', 'Enter file extension', S) then
  begin
    if S[1] <> '.' then
      Insert('.', S, 1);
    if not StrInList(S,ListBackUpTypes.Items)then
    ListBackUpTypes.Items.Add(S);
  end;
end;

procedure TDevToolsForm.CmdBackUpRemoveType;
begin
  ListBackUpTypes.DeleteSelected;
end;

procedure TDevToolsForm.CmdBackUpNewSrcDir;
var Dir: string;
    L:LongInt;
begin
  if SelectDirectory('Select Directory', FSelDirRoot, Dir) then
   begin
   ListBackUpSrcDirs.AddItem(Dir,nil);
   L:=ListBackUpSrcDirs.Canvas.TextWidth(ListBackUpSrcDirs.Items[ListBackUpSrcDirs.Count-1])*130 div 100;
   if L>ListBackUpSrcDirs.ScrollWidth then
   ListBackUpSrcDirs.ScrollWidth:=L;
   end;
end;

procedure TDevToolsForm.CmdBackUpNewDestDir;
var Dir: string;
    L:LongInt;
begin
  if SelectDirectory('Select Directory', FSelDirRoot, Dir) then
   begin
   ListBackUpDestDirs.AddItem(Dir,nil);
   L:=ListBackUpDestDirs.Canvas.TextWidth(ListBackUpDestDirs.Items[ListBackUpDEstDirs.Count-1])*130 div 100;
   if L>ListBackUpDestDirs.ScrollWidth then
   ListBackUpDEstDirs.ScrollWidth:=L;
   end;
end;

procedure TDevToolsForm.CmdBackUpRemoveSrcDir;
begin
  ListBackUpSrcDirs.DeleteSelected;
end;

procedure TDevToolsForm.CmdBackUpRemoveDestDir;
begin
  ListBackUpDestDirs.DeleteSelected;
end;

procedure TDevToolsForm.CmdBackUpProcess;
begin
  ProcessBackUp(ListBackUpTypes.Items,
                ListBackUpSrcDirs.Items,
                ListBackUpDestDirs.Items,
                EditBackUpNewDir.Text,
                CheckBackUpAllTypes.Checked);
end;

procedure TDevToolsForm.CmdSrcSizeNewType;
var S: string;
begin
  if InputQuery('New File Type', 'Enter file extension', S) then
  begin
    if S[1] <> '.' then
      Insert('.', S, 1);
    if not StrInList(S,ListSrcSizeTypes.Items)then
    ListSrcSizeTypes.Items.Add(S);
  end;
end;

procedure TDevToolsForm.CmdSrcSizeRemoveType;
begin
  ListSrcSizeTypes.DeleteSelected;
end;

procedure TDevToolsForm.CmdSrcSizeNewDir;
var Dir: string;
    L:LongInt;
begin
  if SelectDirectory('Select Directory', FSelDirRoot, Dir) then
   begin
   ListSrcSizeDirs.AddItem(Dir,nil);
   L:=ListSrcSizeDirs.Canvas.TextWidth(ListSrcSizeDirs.Items[ListSrcSizeDirs.Count-1])*130 div 100;
   if L>ListSrcSizeDirs.ScrollWidth then
   ListSrcSizeDirs.ScrollWidth:=L;
   end;
end;

procedure TDevToolsForm.CmdSrcSizeRemoveDir;
begin
 ListSrcSizeDirs.DeleteSelected;
end;

procedure TDevToolsForm.CmdSrcSizeProcess;
begin
  ProcessSrcSize(ListSrcSizeTypes.Items,
                ListSrcSizeDirs.Items,
                CheckSrcSizeAllTypes.Checked);
end;

procedure TDevToolsForm.CmdDirCleanNewType;
var S: string;
begin
  if InputQuery('New File Type', 'Enter file extension', S) then
  begin
    if S[1] <> '.' then
      Insert('.', S, 1);
    if not StrInList(S,ListDirCleanTypes.Items)then
    ListDirCleanTypes.Items.Add(S);
  end;
end;

procedure TDevToolsForm.CmdDirCleanRemoveType;
begin
  ListDirCleanTypes.DeleteSelected;
end;

procedure TDevToolsForm.CmdDirCleanNewDir;
var Dir: string;
    L:LongInt;
begin
  if SelectDirectory('Select Directory', FSelDirRoot, Dir) then
   begin
   ListDirCleanDirs.AddItem(Dir,nil);
   L:=ListDirCleanDirs.Canvas.TextWidth(ListDirCleanDirs.Items[ListDirCleanDirs.Count-1])*130 div 100;
   if L>ListDirCleanDirs.ScrollWidth then
   ListDirCleanDirs.ScrollWidth:=L;
   end;
end;

procedure TDevToolsForm.CmdDirCleanRemoveDir;
begin
 ListDirCleanDirs.DeleteSelected;
end;

procedure TDevToolsForm.CmdDirCleanProcess;
begin
  ProcessDirClean(ListDirCleanTypes.Items,
                ListDirCleanDirs.Items);
end;


procedure TDevToolsForm.About1Click(Sender: TObject);
begin
  CmdAbout;
end;

procedure TDevToolsForm.Exit1Click(Sender: TObject);
begin
  CmdExit;
end;

procedure TDevToolsForm.FormClose(Sender: TObject;
  var Action: TCloseAction);
begin
  CmdWriteSettings;
end;

procedure TDevToolsForm.FormActivate(Sender: TObject);
begin
  if FFirstShow then
  begin
    CmdReadSettings;
    FFirstShow := false;
  end;
end;

procedure TDevToolsForm.Button1Click(Sender: TObject);
begin
  CmdBackUpNewType;
end;

procedure TDevToolsForm.Button2Click(Sender: TObject);
begin
  CmdBackUpRemoveType;
end;

procedure TDevToolsForm.BtrnClick(Sender: TObject);
begin
  CmdBackUpNewSrcDir;
end;

procedure TDevToolsForm.Button3Click(Sender: TObject);
begin
 CmdBackUpNewDestDir;
end;

procedure TDevToolsForm.Button4Click(Sender: TObject);
begin
  CmdBackUpRemoveSrcDir;
end;

procedure TDevToolsForm.Button5Click(Sender: TObject);
begin
  CmdBackUpRemoveDestDir;
end;

procedure TDevToolsForm.BitBtn1Click(Sender: TObject);
begin
CmdBackUpProcess;
end;

procedure TDevToolsForm.SourceBackUp2Click(Sender: TObject);
begin
CmdBackUpProcess;
end;

procedure TDevToolsForm.BtnSrcSizeNewTypeClick(Sender: TObject);
begin
CmdSrcSizeNewType;
end;

procedure TDevToolsForm.Button7Click(Sender: TObject);
begin
CmdSrcSizeRemoveType;
end;

procedure TDevToolsForm.Button6Click(Sender: TObject);
begin
CmdSrcSizeNewDir;
end;

procedure TDevToolsForm.Button8Click(Sender: TObject);
begin
CmdSrcSizeRemoveDir;
end;

procedure TDevToolsForm.BitBtn3Click(Sender: TObject);
begin
CmdSrcSizeProcess;
end;

procedure TDevToolsForm.Button9Click(Sender: TObject);
begin
CmdDirCleanNewType;
end;

procedure TDevToolsForm.Button10Click(Sender: TObject);
begin
CmdDirCleanRemoveType;
end;

procedure TDevToolsForm.Button11Click(Sender: TObject);
begin
CmdDirCleanNewDir;
end;

procedure TDevToolsForm.Button12Click(Sender: TObject);
begin
CmdDirCleanRemoveDir;
end;

procedure TDevToolsForm.BitBtn2Click(Sender: TObject);
begin
CmdDirCleanProcess;
end;

procedure TDevToolsForm.SourceSizeCounter2Click(Sender: TObject);
begin
CmdSrcSizeProcess;
end;

procedure TDevToolsForm.DirectoryCleaner2Click(Sender: TObject);
begin
CmdDirCleanProcess;
end;

procedure TDevToolsForm.SourceBackUp1Click(Sender: TObject);
begin
Pages.ActivePage:=PageBackUp;
end;

procedure TDevToolsForm.SourceSizeCounter1Click(Sender: TObject);
begin
Pages.ActivePage:=PageSrcSize;
end;

procedure TDevToolsForm.DirectoryCleaner1Click(Sender: TObject);
begin
Pages.ActivePage:=PageCleaner;
end;

end.

