unit SourceBackUp;

interface

uses Windows, Classes, SysUtils, Forms, Dialogs, ProgressWin,
  WinUtils,ShellAPI;

procedure ProcessBackUp(ATypes, ASrcDirs, ADestDirs: TStrings;
  ANewDir: string; AAllTypes: boolean);


implementation

uses SourceSize;

type

  TBackUpThread = class(TThread)
  private
    FOnce: boolean;
  protected
    procedure Execute; override;
  end;


var Types, SrcDirs, DestDirs: TStrings;
  Files: TStringList;
  AllTypes: boolean;
  NewDir: string;
  Thrd: TBackUpThread;
  FOp:TSHFileOpStruct;
  FilesCopied:LongInt;
  FilesSize:Int64;

procedure TBackUpThread.Execute;
var I, J, K: LongInt;
  S: string;
  Found: TStringList;
  ProgRise:single;
  RealProg:single;
  FSize,TotSize:Int64;
begin
  while (not Terminated) and (not FOnce) do
  begin
    FOnce := true;
    FilesCopied:=0;
    Files := TStringList.Create;
    Found := TStringList.Create;

    for I := 0 to SrcDirs.Count - 1 do
    begin
      if not AllTypes then
        for J := 0 to Types.Count - 1 do
        begin
          AdvBuildFileList(SrcDirs[I] + '\*' + Types[J], faAnyFile, Files,
            [flFullNames, flRecursive]);
          Found.AddStrings(Files);
        end
      else
      begin
        AdvBuildFileList(SrcDirs[I] + '\*.*', faAnyFile, Files,
          [flFullNames, flRecursive]);
        Found.AddStrings(Files);
      end;
    end;

    TotSize := 0;

    for I := 0 to Found.Count - 1 do
    begin
      if FileExists(Found[I])then
      begin
      FSize := FileSize(Found[I]);
      TotSize := TotSize + FSize;
      end;
    end;

    RealProg := 0;
    ProgRise := 100 / (TotSize*DestDirs.Count+1);

    Files.Clear;
    Found.Clear;



    if not ForceDirectories(DestDirs[0] + '\' + NewDir) then
    begin
      raise Exception.Create('Source BackUp Error' +
        #10 + 'Can not create directory "' + DestDirs[0] + '\' + NewDir + '"');
      Suspend;
      Exit;
    end;


    for I := 0 to SrcDirs.Count - 1 do
    begin
      Files.Clear;

      if not AllTypes then
      for J := 0 to Types.Count - 1 do
      begin
        AdvBuildFileList(SrcDirs[I] + '\*' + Types[J], faAnyFile, Found,
          [flFullNames, flRecursive]);

        for K := 0 to Found.Count - 1 do
        begin
          S := ExtractRelativePath(DirUp(SrcDirs[I]) + '\', Found[K]);
          S := ExtractFileDir(S);
          ForceDirectories(DestDirs[0] + '\' + NewDir + '\' + S);

          CopyFile(PChar(Found[K]), PChar(DestDirs[0] + '\' + NewDir + '\' + S +
            '\' + ExtractFileName(Found[K])), false);

          Inc(FilesCopied);

          ProgressForm.LabProcess.Caption:='Copying file : '+ExtractFileName(Found[K]);

          RealProg := RealProg + ProgRise*FileSize(Found[K]);
      if RealProg < 99 then
        ProgressForm.SetProgress(Round(RealProg));

       end;

      end
     else
      begin
       AdvBuildFileList(SrcDirs[I] + '\*.*', faAnyFile, Found,
          [flFullNames, flRecursive]);

       for K := 0 to Found.Count - 1 do
        begin
          S := ExtractRelativePath(DirUp(SrcDirs[I]) + '\', Found[K]);
          S := ExtractFileDir(S);
          ForceDirectories(DestDirs[0] + '\' + NewDir + '\' + S);

          CopyFile(PChar(Found[K]), PChar(DestDirs[0] + '\' + NewDir + '\' + S +
            '\' + ExtractFileName(Found[K])), false);

          Inc(FilesCopied);

          ProgressForm.LabProcess.Caption:='Copying file : '+ExtractFileName(Found[K]);

          RealProg := RealProg + ProgRise;
      if RealProg < 99 then
        ProgressForm.SetProgress(Round(RealProg));

       end;

      end;




    end;



    for I:=1 to DestDirs.Count-1 do
    begin
    ZeroMemory(@FOp,SizeOf(FOp));
    FOp.Wnd:=0;
    FOp.wFunc:=FO_COPY;
    FOp.fFlags:=FOF_SILENT or FOF_NOCONFIRMATION or FOF_NOCONFIRMMKDIR;
    FOp.pFrom:=PChar(DestDirs[0]+'\'+NewDir+'\*'+#0);
    ForceDirectories(DestDirs[I]+'\'+NewDir);
    FOp.pTo:=PChar(DestDirs[I]+'\'+NewDir+#0);

    ProgressForm.LabProcess.Caption:='Copying directory '+NewDir+' to '+DestDirs[I];

    SHFileOperation(FOp);

    RealProg := RealProg + ProgRise*TotSize;
      if RealProg < 99 then
        ProgressForm.SetProgress(Round(RealProg));

    end;

    FilesSize:=TotSize;//*DestDirs.Count;

    Files.Free;
    Found.Free;
    ProgressForm.SetProgress(100);

  end;
end;


procedure ProcessBackUp(ATypes, ASrcDirs, ADestDirs: TStrings;
  ANewDir: string; AAllTypes: boolean);
begin
  if (ASrcDirs.Count = 0) or (ADestDirs.Count = 0) then
  begin
    MessageDlg('Source BackUp Error :' + #10 +
      'Source or Destination Directories not defined!', mtError,
      [mbOK], 0);
    Exit;
  end;

  if (ATypes.Count = 0) and (not AAllTypes) then
  begin
    MessageDlg('Source BackUp Error :' + #10 +
      'File Types not defined!', mtError,
      [mbOK], 0);
    Exit;
  end;

  Types := ATypes;
  SrcDirs := ASrcDirs;
  DestDirs := ADestDirs;
  AllTypes := AAllTypes;
  NewDir := ANewDir;

  if ProgressForm = nil then
    Application.CreateForm(TProgressForm, ProgressForm);

  Thrd := TBackUpThread.Create(true);
  Thrd.Resume;

  ProgressForm.ShowProgress('Processing Source BackUp', '', 0, 100, false);

  Thrd.Free;

  MessageDlg('Source BackUp Comleted'+#10+
  Format('Copied %d files of size:  %.0n Bytes ( %n kB ; %n MB)',
  [FilesCopied,FilesSize/1,FilesSize/1024,FilesSize/1024/1024])+#10+
  Format('Files copied %d times.Total size: %n MB',[DestDirs.Count,FilesSize*DestDirs.Count/1024/1024])+
  #10+'                                          ',
   mtInformation,[mbOK],0);

end;



end.

