unit PathWin;

interface

uses
  Windows, Messages, SysUtils, Variants, Classes, Graphics, Controls, Forms,
  Dialogs, VampyreAboutDlg, Menus, XPMan, XPMenu, ExtCtrls, ComCtrls,
  StdCtrls, Buttons, Registry, WinUtils, FileCtrl, ShellAPI;

type
  TPathForm = class(TForm)
    MainMenu1: TMainMenu;
    XPMenu: TXPMenu;
    XPMan: TXPManifest;
    File1: TMenuItem;
    Help1: TMenuItem;
    Abou1: TMenuItem;
    Exit1: TMenuItem;
    Panel1: TPanel;
    GroupBox1: TGroupBox;
    EdPath: TLabeledEdit;
    Button1: TButton;
    RGroup: TRadioGroup;
    GroupBox2: TGroupBox;
    CheckFiles: TCheckBox;
    CheckHREFS: TCheckBox;
    GroupBox3: TGroupBox;
    ListTypes: TListBox;
    Button2: TButton;
    Button3: TButton;
    BitBtn1: TBitBtn;
    CheckDirs: TCheckBox;
    procedure Exit1Click(Sender: TObject);
    procedure Abou1Click(Sender: TObject);
    procedure FormCreate(Sender: TObject);
    procedure FormActivate(Sender: TObject);
    procedure Button2Click(Sender: TObject);
    procedure Button3Click(Sender: TObject);
    procedure Button1Click(Sender: TObject);
    procedure FormClose(Sender: TObject; var Action: TCloseAction);
    procedure BitBtn1Click(Sender: TObject);
  private
    FFirstShow: boolean;
    FLinks:TStringList;
    { Private declarations }
  public

    procedure CmdReadSettings;
    procedure CmdFirstRun;
    procedure CmdNewType;
    procedure CmdRemoveType;
    procedure CmdBrowse;
    procedure CmdWriteSettings;
    procedure CmdProcess;
    { Public declarations }
  end;

const

  sApp = 'Vampyre Path Checker';
  sAppVer = 'Version 0.40  13.12.2002';

  sKeyApp = 'SoftWare\Vampyre SoftWorks\Utils\Path Checker';

  ExtsDef: array[0..5] of string =
  ('.htm', '.html', '.mht', '.asp', '.php', '.shtml');

  LinksDef:array[0..3]of string =
  ('href', 'name', 'src', 'background');


var
  PathForm: TPathForm;

implementation

{$R *.dfm}

procedure TPathForm.Exit1Click(Sender: TObject);
begin
  FLinks.Free;
  Close;
end;

procedure TPathForm.Abou1Click(Sender: TObject);
begin
  if AboutForm = nil then
  begin
    Application.CreateForm(TAboutForm, AboutForm);
    AboutForm.Memo.Lines.Insert(0, sApp);
    AboutForm.Memo.Lines.Insert(1, sAppVer);
  end;
  AboutForm.ShowModal;
end;

procedure TPathForm.FormCreate(Sender: TObject);
begin
  FFirstShow := true;
  FLinks:=TStringList.Create;
end;

procedure TPathForm.FormActivate(Sender: TObject);
begin
  if FFirstShow then
  begin
    CmdReadSettings;
    FFirstShow := false;
  end;
end;

procedure TPathForm.CmdReadSettings;
var Reg: TRegistry;
  S: string;
begin
  Reg := TRegistry.Create(KEY_ALL_ACCESS);
  Reg.RootKey := HKEY_LOCAL_MACHINE;
  if not Reg.KeyExists(sKeyApp) then
    CmdFirstRun;

  Reg.OpenKey(sKeyApp, true);

  S := Reg.ReadString('File Types');
  StrTokenToStrings(S, ';', ListTypes.Items);
  S := Reg.ReadString('Link Types');
  StrTokenToStrings(S, ';', FLinks);
  EdPath.Text := Reg.ReadString('Dir');
  RGroup.ItemIndex := Byte(not Reg.ReadBool('LowerCase'));
  CheckFiles.Checked := Reg.ReadBool('ChkFiles');
  CheckHREFs.Checked := Reg.ReadBool('ChkHREFs');
  CheckDirs.Checked := Reg.ReadBool('ChkDirs');


  Reg.Free;

end;

procedure TPathForm.CmdWriteSettings;
var Reg: TRegistry;
  S: string;
begin
  Reg := TRegistry.Create(KEY_ALL_ACCESS);
  Reg.RootKey := HKEY_LOCAL_MACHINE;

  Reg.OpenKey(sKeyApp, true);

  S := ComposeString(ListTypes.Items, ';');
  Reg.WriteString('File Types', S);
  S := ComposeString(FLinks, ';');
  Reg.WriteString('Link Types', S);

  Reg.WriteString('Dir', EdPath.Text);
  Reg.WriteBool('LowerCase', not Boolean(RGroup.ItemIndex));
  Reg.WriteBool('ChkFiles', CheckFiles.Checked);
  Reg.WriteBool('ChkHREFs', CheckHREFs.Checked);
  Reg.WriteBool('ChkDirs', CheckDirs.Checked);


  Reg.Free;
end;

procedure TPathForm.CmdFirstRun;
var Reg: TRegistry;
  S: string;
  I: LongInt;
begin
  MessageDlg('You are running Vampyre Path Checker for first time.' +
    #10 + 'Program will use default settings.', mtInformation, [mbOK], 0);

  Reg := TRegistry.Create(KEY_ALL_ACCESS);
  Reg.RootKey := HKEY_LOCAL_MACHINE;

  Reg.OpenKey(sKeyApp, true);

  S := '';
  for I := 0 to High(ExtsDef) do
    S := S + ExtsDef[I] + ';';
  Delete(S, Length(S), 1);
  Reg.WriteString('File Types', S);
  S := '';
  for I := 0 to High(LinksDef) do
    S := S + LinksDef[I] + ';';
  Delete(S, Length(S), 1);
  Reg.WriteString('Link Types', S);
  Reg.WriteString('Dir', '');

  Reg.WriteBool('LowerCase', true);
  Reg.WriteBool('ChkFiles', true);
  Reg.WriteBool('ChkHREFs', true);
  Reg.WriteBool('ChkDirs', true);

  Reg.CloseKey;


  Reg.Free;

end;

procedure TPathForm.CmdRemoveType;
begin
  ListTypes.DeleteSelected;
end;

procedure TPathForm.CmdNewType;
var S: string;
begin
  if InputQuery('New File Type', 'Enter file extension', S) then
  begin
    if S[1] <> '.' then
      Insert('.', S, 1);
    if not StrInList(S, ListTypes.Items) then
      ListTypes.Items.Add(S);
  end;
end;

procedure TPathForm.CmdBrowse;
var Dir: string;
begin
  if SelectDirectory('Select Directory', '', Dir) then
  begin
    EdPath.Text := Dir;
  end;
end;

procedure TPathForm.CmdProcess;
var Dir:string;
    AllFiles:TStringList;
    Dirs:TStringList;
    Pages:TStringList;
    LastK,I,J,K:LongInt;
    C:Char;
    S,SS:String;
    FOp:TSHFileOpStruct;

label Top;

begin
 Dir:=EdPath.Text;
 if not DirectoryExists(Dir) then
  begin
    MessageDlg('Path Checker Error :' + #10 +
      'Directory not defined!', mtError,
      [mbOK], 0);
    Exit;
  end;

 if CheckDirs.Checked then
 begin
 Dirs:=TStringList.Create;
 AdvBuildFileList(Dir+'\',faDirectory,Dirs,[flRecursive,flFullNames]);

 for I:=1 to Dirs.Count-1 do
 begin
 ZeroMemory(@FOp,SizeOf(FOp));
 FOp.Wnd:=Handle;
 FOp.wFunc:=FO_RENAME;
 FOp.fFlags:=FOF_SILENT or FOF_NOCONFIRMATION or FOF_NOCONFIRMMKDIR;
 Dirs[I]:=ExcludeTrailingPathDelimiter(Dirs[I]);
 FOp.pFrom:=PChar(Dirs[I]+#0);
 if RGroup.ItemIndex=0 then
 S:=AnsiLowerCase(ExtractFileName(Dirs[I]))
 else
 S:=AnsiUpperCase(ExtractFileName(Dirs[I]));
 FOp.pTo:=PChar(ExtractFileDir(Dirs[I])+'\'+ S+#0);
 if AnsiCompareStr(FOp.pFrom,FOp.pTo)<>0 then
 SHFileOperation(FOp);
 end;
 Dirs.Free;
 end;

 AllFiles:=TStringList.Create;
 AdvBuildFileList(Dir+'\*.*',faAnyFile,AllFiles,[flRecursive,flFullNames]);

 if CheckFiles.Checked then
 begin
 for I:=0 to AllFiles.Count-1 do
 begin
 ZeroMemory(@FOp,SizeOf(FOp));
 FOp.Wnd:=Handle;
 FOp.wFunc:=FO_RENAME;
 FOp.fFlags:=FOF_SILENT or FOF_NOCONFIRMATION or FOF_NOCONFIRMMKDIR;
 FOp.pFrom:=PChar(AllFiles[I]+#0);
 if RGroup.ItemIndex=0 then
 S:=AnsiLowerCase(ExtractFileName(AllFiles[I]))
 else
 S:=AnsiUpperCase(ExtractFileName(AllFiles[I]));
 FOp.pTo:=PChar(ExtractFileDir(AllFiles[I])+'\'+ S+#0);
 if AnsiCompareStr(FOp.pFrom,FOp.pTo)<>0 then
 SHFileOperation(FOp);
 end;

 end;

if CheckHREFs.Checked then
begin
 Pages:=TStringList.Create;
 for I:=0 to AllFiles.Count-1 do
 begin
  if StrInList(ExtractFileExt(AllFiles[I]),ListTypes.Items) then
   begin
    Pages.LoadFromFile(AllFiles[I]);

    if Pos('choice.html',AllFiles[I])>0then
     Sleep(1);

    for J:=0 to Pages.Count-1 do
     begin
     K:=1;
     LastK:=0;
 Top:while K>0 do
     begin

     K:=StrListPos(Pages[J],FLinks,LastK);
          if K>0 then
     begin
      LastK:=K;

      C:=#0;
      while C<>'=' do
       begin
        if K>Length(Pages[J]) then goto Top;
        C:=Pages[J][K];
        Inc(K);
       end;

      C:=Pages[J][K];
      Inc(K);

      while C<>'"' do
       begin
        if K>Length(Pages[J]) then goto Top;
        C:=Pages[J][K];
        Inc(K);
       end;

      C:=Pages[J][K];

      while C<>'"' do
      begin
       SS:=Pages[J];
       if RGroup.ItemIndex=0 then
       SS[K]:=AnsiLowerCase(C)[1]
       else
       SS[K]:=AnsiUpperCase(C)[1];
       Pages[J]:=SS;

       Inc(K);
       C:=Pages[J][K];
      end;



     end;
      end;
     end;
   Pages.SaveToFile(AllFiles[I]);
   end;
 end;
 Pages.Free;
end;

AllFiles.Free;

end;

procedure TPathForm.Button2Click(Sender: TObject);
begin
  CmdNewType;
end;

procedure TPathForm.Button3Click(Sender: TObject);
begin
  CmdRemoveType;
end;

procedure TPathForm.Button1Click(Sender: TObject);
begin
  CmdBrowse;
end;

procedure TPathForm.FormClose(Sender: TObject; var Action: TCloseAction);
begin
  CmdWriteSettings;
end;

procedure TPathForm.BitBtn1Click(Sender: TObject);
begin
  CmdProcess;
end;

end.

